@@ -23,14 +23,13 @@ class BalanceRecord(BaseModel):
 
 
 class BalancesMeta(BaseModel):
+    account_types: Optional[str]
+    labels: Optional[str]
     page: int
     utc_starttime: Optional[datetime] = None
     utc_endtime: Optional[datetime] = None
-    institution_id: str
-    user_uuid: str
     total_balances_count: int
     max_pages: int
-    client_uuid: str
 
 
 class BalancesAccount(BaseModel):
