@@ -15,7 +15,7 @@ PATH = "/users/{user_uuid}/institutions/{institution_id}/transactions"
 class TransactionRecord(BaseModel):
     ts: int
     description: Optional[str]
-    amount: int
+    amount: float
     impact: str
     account_id: str
     account_type: Optional[str]
@@ -87,6 +87,7 @@ class BaseTransactionsResource(ABC):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[TransactionRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -95,9 +96,10 @@ class BaseTransactionsResource(ABC):
             utc_endtime=utc_endtime,
             labels=labels,
             account_types=account_types,
+            page=page or 1,
         )
         max_pages = response.meta.max_pages
-        if max_pages > 1:
+        if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
                     user_uuid=user_uuid,
@@ -133,6 +135,7 @@ class AsyncTransactionsResource(BaseTransactionsResource):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[TransactionRecord]:
         return await self._get(
             user_uuid=user_uuid,
@@ -141,6 +144,7 @@ class AsyncTransactionsResource(BaseTransactionsResource):
             utc_endtime=utc_endtime,
             labels=labels,
             account_types=account_types,
+            page=page,
         )
 
 
@@ -154,6 +158,7 @@ class SyncTransactionsResource(BaseTransactionsResource):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[TransactionRecord]:
         return self._client.run(
             self._get(
@@ -163,5 +168,6 @@ class SyncTransactionsResource(BaseTransactionsResource):
                 utc_endtime=utc_endtime,
                 labels=labels,
                 account_types=account_types,
+                page=page,
             )
         )
